# File for configuration of the stockdex package

BASE_URL = "https://query2.finance.yahoo.com/v8/finance"
FUNDAMENTALS_BASE_URL = (
    "https://query2.finance.yahoo.com/ws/fundamentals-timeseries/v1/finance/timeseries"
)

QUARTERLY_INCOME_STATEMENT_COLUMNS = [
    "quarterlyTaxEffectOfUnusualItems",
    "quarterlyTaxRateForCalcs",
    "quarterlyNormalizedEBITDA",
    "quarterlyNormalizedDilutedEPS",
    "quarterlyNormalizedBasicEPS",
    "quarterlyTotalUnusualItems",
    "quarterlyTotalUnusualItemsExcludingGoodwill",
    "quarterlyNetIncomeFromContinuingOperationNetMinorityInterest",
    "quarterlyReconciledDepreciation",
    "quarterlyReconciledCostOfRevenue",
    "quarterlyEBITDA",
    "quarterlyEBIT",
    "quarterlyNetInterestIncome",
    "quarterlyInterestExpense",
    "quarterlyInterestIncome",
    "quarterlyContinuingAndDiscontinuedDilutedEPS",
    "quarterlyContinuingAndDiscontinuedBasicEPS",
    "quarterlyNormalizedIncome",
    "quarterlyNetIncomeFromContinuingAndDiscontinuedOperation",
    "quarterlyTotalExpenses",
    "quarterlyRentExpenseSupplemental",
    "quarterlyReportedNormalizedDilutedEPS",
    "quarterlyReportedNormalizedBasicEPS",
    "quarterlyTotalOperatingIncomeAsReported",
    "quarterlyDividendPerShare",
    "quarterlyDilutedAverageShares",
    "quarterlyBasicAverageShares",
    "quarterlyDilutedEPS",
    "quarterlyDilutedEPSOtherGainsLosses",
    "quarterlyTaxLossCarryforwardDilutedEPS",
    "quarterlyDilutedAccountingChange",
    "quarterlyDilutedExtraordinary",
    "quarterlyDilutedDiscontinuousOperations",
    "quarterlyDilutedContinuousOperations",
    "quarterlyBasicEPS",
    "quarterlyBasicEPSOtherGainsLosses",
    "quarterlyTaxLossCarryforwardBasicEPS",
    "quarterlyBasicAccountingChange",
    "quarterlyBasicExtraordinary",
    "quarterlyBasicDiscontinuousOperations",
    "quarterlyBasicContinuousOperations",
    "quarterlyDilutedNIAvailtoComStockholders",
    "quarterlyAverageDilutionEarnings",
    "quarterlyNetIncomeCommonStockholders",
    "quarterlyOtherunderPreferredStockDividend",
    "quarterlyPreferredStockDividends",
    "quarterlyNetIncome",
    "quarterlyMinorityInterests",
    "quarterlyNetIncomeIncludingNoncontrollingInterests",
    "quarterlyNetIncomeFromTaxLossCarryforward",
    "quarterlyNetIncomeExtraordinary",
    "quarterlyNetIncomeDiscontinuousOperations",
    "quarterlyNetIncomeContinuousOperations",
    "quarterlyEarningsFromEquityInterestNetOfTax",
    "quarterlyTaxProvision",
    "quarterlyPretaxIncome",
    "quarterlyOtherIncomeExpense",
    "quarterlyOtherNonOperatingIncomeExpenses",
    "quarterlySpecialIncomeCharges",
    "quarterlyGainOnSaleOfPPE",
    "quarterlyGainOnSaleOfBusiness",
    "quarterlyOtherSpecialCharges",
    "quarterlyWriteOff",
    "quarterlyImpairmentOfCapitalAssets",
    "quarterlyRestructuringAndMergernAcquisition",
    "quarterlySecuritiesAmortization",
    "quarterlyEarningsFromEquityInterest",
    "quarterlyGainOnSaleOfSecurity",
    "quarterlyNetNonOperatingInterestIncomeExpense",
    "quarterlyTotalOtherFinanceCost",
    "quarterlyInterestExpenseNonOperating",
    "quarterlyInterestIncomeNonOperating",
    "quarterlyOperatingIncome",
    "quarterlyOperatingExpense",
    "quarterlyOtherOperatingExpenses",
    "quarterlyOtherTaxes",
    "quarterlyProvisionForDoubtfulAccounts",
    "quarterlyDepreciationAmortizationDepletionIncomeStatement",
    "quarterlyDepletionIncomeStatement",
    "quarterlyDepreciationAndAmortizationInIncomeStatement",
    "quarterlyAmortization",
    "quarterlyAmortizationOfIntangiblesIncomeStatement",
    "quarterlyDepreciationIncomeStatement",
    "quarterlyResearchAndDevelopment",
    "quarterlySellingGeneralAndAdministration",
    "quarterlySellingAndMarketingExpense",
    "quarterlyGeneralAndAdministrativeExpense",
    "quarterlyOtherGandA",
    "quarterlyInsuranceAndClaims",
    "quarterlyRentAndLandingFees",
    "quarterlySalariesAndWages",
    "quarterlyGrossProfit",
    "quarterlyCostOfRevenue",
    "quarterlyTotalRevenue",
    "quarterlyExciseTaxes",
    "quarterlyOperatingRevenue",
]

ANNUAL_INCOME_STATEMENT_COLUMNS = [
    "annualTaxEffectOfUnusualItems",
    "annualTaxRateForCalcs",
    "annualNormalizedEBITDA",
    "annualNormalizedDilutedEPS",
    "annualNormalizedBasicEPS",
    "annualTotalUnusualItems",
    "annualTotalUnusualItemsExcludingGoodwill",
    "annualNetIncomeFromContinuingOperationNetMinorityInterest",
    "annualReconciledDepreciation",
    "annualReconciledCostOfRevenue",
    "annualEBITDA",
    "annualEBIT",
    "annualNetInterestIncome",
    "annualInterestExpense",
    "annualInterestIncome",
    "annualContinuingAndDiscontinuedDilutedEPS",
    "annualContinuingAndDiscontinuedBasicEPS",
    "annualNormalizedIncome",
    "annualNetIncomeFromContinuingAndDiscontinuedOperation",
    "annualTotalExpenses",
    "annualRentExpenseSupplemental",
    "annualReportedNormalizedDilutedEPS",
    "annualReportedNormalizedBasicEPS",
    "annualTotalOperatingIncomeAsReported",
    "annualDividendPerShare",
    "annualDilutedAverageShares",
    "annualBasicAverageShares",
    "annualDilutedEPS",
    "annualDilutedEPSOtherGainsLosses",
    "annualTaxLossCarryforwardDilutedEPS",
    "annualDilutedAccountingChange",
    "annualDilutedExtraordinary",
    "annualDilutedDiscontinuousOperations",
    "annualDilutedContinuousOperations",
    "annualBasicEPS",
    "annualBasicEPSOtherGainsLosses",
    "annualTaxLossCarryforwardBasicEPS",
    "annualBasicAccountingChange",
    "annualBasicExtraordinary",
    "annualBasicDiscontinuousOperations",
    "annualBasicContinuousOperations",
    "annualDilutedNIAvailtoComStockholders",
    "annualAverageDilutionEarnings",
    "annualNetIncomeCommonStockholders",
    "annualOtherunderPreferredStockDividend",
    "annualPreferredStockDividends",
    "annualNetIncome",
    "annualMinorityInterests",
    "annualNetIncomeIncludingNoncontrollingInterests",
    "annualNetIncomeFromTaxLossCarryforward",
    "annualNetIncomeExtraordinary",
    "annualNetIncomeDiscontinuousOperations",
    "annualNetIncomeContinuousOperations",
    "annualEarningsFromEquityInterestNetOfTax",
    "annualTaxProvision",
    "annualPretaxIncome",
    "annualOtherIncomeExpense",
    "annualOtherNonOperatingIncomeExpenses",
    "annualSpecialIncomeCharges",
    "annualGainOnSaleOfPPE",
    "annualGainOnSaleOfBusiness",
    "annualOtherSpecialCharges",
    "annualWriteOff",
    "annualImpairmentOfCapitalAssets",
    "annualRestructuringAndMergernAcquisition",
    "annualSecuritiesAmortization",
    "annualEarningsFromEquityInterest",
    "annualGainOnSaleOfSecurity",
    "annualNetNonOperatingInterestIncomeExpense",
    "annualTotalOtherFinanceCost",
    "annualInterestExpenseNonOperating",
    "annualInterestIncomeNonOperating",
    "annualOperatingIncome",
    "annualOperatingExpense",
    "annualOtherOperatingExpenses",
    "annualOtherTaxes",
    "annualProvisionForDoubtfulAccounts",
    "annualDepreciationAmortizationDepletionIncomeStatement",
    "annualDepletionIncomeStatement",
    "annualDepreciationAndAmortizationInIncomeStatement",
    "annualAmortization",
    "annualAmortizationOfIntangiblesIncomeStatement",
    "annualDepreciationIncomeStatement",
    "annualResearchAndDevelopment",
    "annualSellingGeneralAndAdministration",
    "annualSellingAndMarketingExpense",
    "annualGeneralAndAdministrativeExpense",
    "annualOtherGandA",
    "annualInsuranceAndClaims",
    "annualRentAndLandingFees",
    "annualSalariesAndWages",
    "annualGrossProfit",
    "annualCostOfRevenue",
    "annualTotalRevenue",
    "annualExciseTaxes",
    "annualOperatingRevenue",
]

ANNUAL_CASH_FLOW_COLUMNS = [
    "annualForeignSales",
    "annualDomesticSales",
    "annualAdjustedGeographySegmentData",
    "annualFreeCashFlow",
    "annualRepurchaseOfCapitalStock",
    "annualRepaymentOfDebt",
    "annualIssuanceOfDebt",
    "annualIssuanceOfCapitalStock",
    "annualCapitalExpenditure",
    "annualInterestPaidSupplementalData",
    "annualIncomeTaxPaidSupplementalData",
    "annualEndCashPosition",
    "annualOtherCashAdjustmentOutsideChangeinCash",
    "annualBeginningCashPosition",
    "annualEffectOfExchangeRateChanges",
    "annualChangesInCash",
    "annualOtherCashAdjustmentInsideChangeinCash",
    "annualCashFlowFromDiscontinuedOperation",
    "annualFinancingCashFlow",
    "annualCashFromDiscontinuedFinancingActivities",
    "annualCashFlowFromContinuingFinancingActivities",
    "annualNetOtherFinancingCharges",
    "annualInterestPaidCFF",
    "annualProceedsFromStockOptionExercised",
    "annualCashDividendsPaid",
    "annualPreferredStockDividendPaid",
    "annualCommonStockDividendPaid",
    "annualNetPreferredStockIssuance",
    "annualPreferredStockPayments",
    "annualPreferredStockIssuance",
    "annualNetCommonStockIssuance",
    "annualCommonStockPayments",
    "annualCommonStockIssuance",
    "annualNetIssuancePaymentsOfDebt",
    "annualNetShortTermDebtIssuance",
    "annualShortTermDebtPayments",
    "annualShortTermDebtIssuance",
    "annualNetLongTermDebtIssuance",
    "annualLongTermDebtPayments",
    "annualLongTermDebtIssuance",
    "annualInvestingCashFlow",
    "annualCashFromDiscontinuedInvestingActivities",
    "annualCashFlowFromContinuingInvestingActivities",
    "annualNetOtherInvestingChanges",
    "annualInterestReceivedCFI",
    "annualDividendsReceivedCFI",
    "annualNetInvestmentPurchaseAndSale",
    "annualSaleOfInvestment",
    "annualPurchaseOfInvestment",
    "annualNetInvestmentPropertiesPurchaseAndSale",
    "annualSaleOfInvestmentProperties",
    "annualPurchaseOfInvestmentProperties",
    "annualNetBusinessPurchaseAndSale",
    "annualSaleOfBusiness",
    "annualPurchaseOfBusiness",
    "annualNetIntangiblesPurchaseAndSale",
    "annualSaleOfIntangibles",
    "annualPurchaseOfIntangibles",
    "annualNetPPEPurchaseAndSale",
    "annualSaleOfPPE",
    "annualPurchaseOfPPE",
    "annualCapitalExpenditureReported",
    "annualOperatingCashFlow",
    "annualCashFromDiscontinuedOperatingActivities",
    "annualCashFlowFromContinuingOperatingActivities",
    "annualTaxesRefundPaid",
    "annualInterestReceivedCFO",
    "annualInterestPaidCFO",
    "annualDividendReceivedCFO",
    "annualDividendPaidCFO",
    "annualChangeInWorkingCapital",
    "annualChangeInOtherWorkingCapital",
    "annualChangeInOtherCurrentLiabilities",
    "annualChangeInOtherCurrentAssets",
    "annualChangeInPayablesAndAccruedExpense",
    "annualChangeInAccruedExpense",
    "annualChangeInInterestPayable",
    "annualChangeInPayable",
    "annualChangeInDividendPayable",
    "annualChangeInAccountPayable",
    "annualChangeInTaxPayable",
    "annualChangeInIncomeTaxPayable",
    "annualChangeInPrepaidAssets",
    "annualChangeInInventory",
    "annualChangeInReceivables",
    "annualChangesInAccountReceivables",
    "annualOtherNonCashItems",
    "annualExcessTaxBenefitFromStockBasedCompensation",
    "annualStockBasedCompensation",
    "annualUnrealizedGainLossOnInvestmentSecurities",
    "annualProvisionandWriteOffofAssets",
    "annualAssetImpairmentCharge",
    "annualAmortizationOfSecurities",
    "annualDeferredTax",
    "annualDeferredIncomeTax",
    "annualDepreciationAmortizationDepletion",
    "annualDepletion",
    "annualDepreciationAndAmortization",
    "annualAmortizationCashFlow",
    "annualAmortizationOfIntangibles",
    "annualDepreciation",
    "annualOperatingGainsLosses",
    "annualPensionAndEmployeeBenefitExpense",
    "annualEarningsLossesFromEquityInvestments",
    "annualGainLossOnInvestmentSecurities",
    "annualNetForeignCurrencyExchangeGainLoss",
    "annualGainLossOnSaleOfPPE",
    "annualGainLossOnSaleOfBusiness",
    "annualNetIncomeFromContinuingOperations",
    "annualCashFlowsfromusedinOperatingActivitiesDirect",
    "annualTaxesRefundPaidDirect",
    "annualInterestReceivedDirect",
    "annualInterestPaidDirect",
    "annualDividendsReceivedDirect",
    "annualDividendsPaidDirect",
    "annualClassesofCashPayments",
    "annualOtherCashPaymentsfromOperatingActivities",
    "annualPaymentsonBehalfofEmployees",
    "annualPaymentstoSuppliersforGoodsandServices",
    "annualClassesofCashReceiptsfromOperatingActivities",
    "annualOtherCashReceiptsfromOperatingActivities",
    "annualReceiptsfromGovernmentGrants",
    "annualReceiptsfromCustomers",
]

QUARTERLY_CASH_FLOW_COLUMNS = [
    "quarterlyForeignSales",
    "quarterlyDomesticSales",
    "quarterlyAdjustedGeographySegmentData",
    "quarterlyFreeCashFlow",
    "quarterlyRepurchaseOfCapitalStock",
    "quarterlyRepaymentOfDebt",
    "quarterlyIssuanceOfDebt",
    "quarterlyIssuanceOfCapitalStock",
    "quarterlyCapitalExpenditure",
    "quarterlyInterestPaidSupplementalData",
    "quarterlyIncomeTaxPaidSupplementalData",
    "quarterlyEndCashPosition",
    "quarterlyOtherCashAdjustmentOutsideChangeinCash",
    "quarterlyBeginningCashPosition",
    "quarterlyEffectOfExchangeRateChanges",
    "quarterlyChangesInCash",
    "quarterlyOtherCashAdjustmentInsideChangeinCash",
    "quarterlyCashFlowFromDiscontinuedOperation",
    "quarterlyFinancingCashFlow",
    "quarterlyCashFromDiscontinuedFinancingActivities",
    "quarterlyCashFlowFromContinuingFinancingActivities",
    "quarterlyNetOtherFinancingCharges",
    "quarterlyInterestPaidCFF",
    "quarterlyProceedsFromStockOptionExercised",
    "quarterlyCashDividendsPaid",
    "quarterlyPreferredStockDividendPaid",
    "quarterlyCommonStockDividendPaid",
    "quarterlyNetPreferredStockIssuance",
    "quarterlyPreferredStockPayments",
    "quarterlyPreferredStockIssuance",
    "quarterlyNetCommonStockIssuance",
    "quarterlyCommonStockPayments",
    "quarterlyCommonStockIssuance",
    "quarterlyNetIssuancePaymentsOfDebt",
    "quarterlyNetShortTermDebtIssuance",
    "quarterlyShortTermDebtPayments",
    "quarterlyShortTermDebtIssuance",
    "quarterlyNetLongTermDebtIssuance",
    "quarterlyLongTermDebtPayments",
    "quarterlyLongTermDebtIssuance",
    "quarterlyInvestingCashFlow",
    "quarterlyCashFromDiscontinuedInvestingActivities",
    "quarterlyCashFlowFromContinuingInvestingActivities",
    "quarterlyNetOtherInvestingChanges",
    "quarterlyInterestReceivedCFI",
    "quarterlyDividendsReceivedCFI",
    "quarterlyNetInvestmentPurchaseAndSale",
    "quarterlySaleOfInvestment",
    "quarterlyPurchaseOfInvestment",
    "quarterlyNetInvestmentPropertiesPurchaseAndSale",
    "quarterlySaleOfInvestmentProperties",
    "quarterlyPurchaseOfInvestmentProperties",
    "quarterlyNetBusinessPurchaseAndSale",
    "quarterlySaleOfBusiness",
    "quarterlyPurchaseOfBusiness",
    "quarterlyNetIntangiblesPurchaseAndSale",
    "quarterlySaleOfIntangibles",
    "quarterlyPurchaseOfIntangibles",
    "quarterlyNetPPEPurchaseAndSale",
    "quarterlySaleOfPPE",
    "quarterlyPurchaseOfPPE",
    "quarterlyCapitalExpenditureReported",
    "quarterlyOperatingCashFlow",
    "quarterlyCashFromDiscontinuedOperatingActivities",
    "quarterlyCashFlowFromContinuingOperatingActivities",
    "quarterlyTaxesRefundPaid",
    "quarterlyInterestReceivedCFO",
    "quarterlyInterestPaidCFO",
    "quarterlyDividendReceivedCFO",
    "quarterlyDividendPaidCFO",
    "quarterlyChangeInWorkingCapital",
    "quarterlyChangeInOtherWorkingCapital",
    "quarterlyChangeInOtherCurrentLiabilities",
    "quarterlyChangeInOtherCurrentAssets",
    "quarterlyChangeInPayablesAndAccruedExpense",
    "quarterlyChangeInAccruedExpense",
    "quarterlyChangeInInterestPayable",
    "quarterlyChangeInPayable",
    "quarterlyChangeInDividendPayable",
    "quarterlyChangeInAccountPayable",
    "quarterlyChangeInTaxPayable",
    "quarterlyChangeInIncomeTaxPayable",
    "quarterlyChangeInPrepaidAssets",
    "quarterlyChangeInInventory",
    "quarterlyChangeInReceivables",
    "quarterlyChangesInAccountReceivables",
    "quarterlyOtherNonCashItems",
    "quarterlyExcessTaxBenefitFromStockBasedCompensation",
    "quarterlyStockBasedCompensation",
    "quarterlyUnrealizedGainLossOnInvestmentSecurities",
    "quarterlyProvisionandWriteOffofAssets",
    "quarterlyAssetImpairmentCharge",
    "quarterlyAmortizationOfSecurities",
    "quarterlyDeferredTax",
    "quarterlyDeferredIncomeTax",
    "quarterlyDepreciationAmortizationDepletion",
    "quarterlyDepletion",
    "quarterlyDepreciationAndAmortization",
    "quarterlyAmortizationCashFlow",
    "quarterlyAmortizationOfIntangibles",
    "quarterlyDepreciation",
    "quarterlyOperatingGainsLosses",
    "quarterlyPensionAndEmployeeBenefitExpense",
    "quarterlyEarningsLossesFromEquityInvestments",
    "quarterlyGainLossOnInvestmentSecurities",
    "quarterlyNetForeignCurrencyExchangeGainLoss",
    "quarterlyGainLossOnSaleOfPPE",
    "quarterlyGainLossOnSaleOfBusiness",
    "quarterlyNetIncomeFromContinuingOperations",
    "quarterlyCashFlowsfromusedinOperatingActivitiesDirect",
    "quarterlyTaxesRefundPaidDirect",
    "quarterlyInterestReceivedDirect",
    "quarterlyInterestPaidDirect",
    "quarterlyDividendsReceivedDirect",
    "quarterlyDividendsPaidDirect",
    "quarterlyClassesofCashPayments",
    "quarterlyOtherCashPaymentsfromOperatingActivities",
    "quarterlyPaymentsonBehalfofEmployees",
    "quarterlyPaymentstoSuppliersforGoodsandServices",
    "quarterlyClassesofCashReceiptsfromOperatingActivities",
    "quarterlyOtherCashReceiptsfromOperatingActivities",
    "quarterlyReceiptsfromGovernmentGrants",
    "quarterlyReceiptsfromCustomer",
]

ANNUAL_BALANCE_SHEET_COLUMNS = [
    "annualTreasurySharesNumber",
    "annualPreferredSharesNumber",
    "annualOrdinarySharesNumber",
    "annualShareIssued",
    "annualNetDebt",
    "annualTotalDebt",
    "annualTangibleBookValue",
    "annualInvestedCapital",
    "annualWorkingCapital",
    "annualNetTangibleAssets",
    "annualCapitalLeaseObligations",
    "annualCommonStockEquity",
    "annualPreferredStockEquity",
    "annualTotalCapitalization",
    "annualTotalEquityGrossMinorityInterest",
    "annualMinorityInterest",
    "annualStockholdersEquity",
    "annualOtherEquityInterest",
    "annualGainsLossesNotAffectingRetainedEarnings",
    "annualOtherEquityAdjustments",
    "annualFixedAssetsRevaluationReserve",
    "annualForeignCurrencyTranslationAdjustments",
    "annualMinimumPensionLiabilities",
    "annualUnrealizedGainLoss",
    "annualTreasuryStock",
    "annualRetainedEarnings",
    "annualAdditionalPaidInCapital",
    "annualCapitalStock",
    "annualOtherCapitalStock",
    "annualCommonStock",
    "annualPreferredStock",
    "annualTotalPartnershipCapital",
    "annualGeneralPartnershipCapital",
    "annualLimitedPartnershipCapital",
    "annualTotalLiabilitiesNetMinorityInterest",
    "annualTotalNonCurrentLiabilitiesNetMinorityInterest",
    "annualOtherNonCurrentLiabilities",
    "annualLiabilitiesHeldforSaleNonCurrent",
    "annualRestrictedCommonStock",
    "annualPreferredSecuritiesOutsideStockEquity",
    "annualDerivativeProductLiabilities",
    "annualEmployeeBenefits",
    "annualNonCurrentPensionAndOtherPostretirementBenefitPlans",
    "annualNonCurrentAccruedExpenses",
    "annualDuetoRelatedPartiesNonCurrent",
    "annualTradeandOtherPayablesNonCurrent",
    "annualNonCurrentDeferredLiabilities",
    "annualNonCurrentDeferredRevenue",
    "annualNonCurrentDeferredTaxesLiabilities",
    "annualLongTermDebtAndCapitalLeaseObligation",
    "annualLongTermCapitalLeaseObligation",
    "annualLongTermDebt",
    "annualLongTermProvisions",
    "annualCurrentLiabilities",
    "annualOtherCurrentLiabilities",
    "annualCurrentDeferredLiabilities",
    "annualCurrentDeferredRevenue",
    "annualCurrentDeferredTaxesLiabilities",
    "annualCurrentDebtAndCapitalLeaseObligation",
    "annualCurrentCapitalLeaseObligation",
    "annualCurrentDebt",
    "annualOtherCurrentBorrowings",
    "annualLineOfCredit",
    "annualCommercialPaper",
    "annualCurrentNotesPayable",
    "annualPensionandOtherPostRetirementBenefitPlansCurrent",
    "annualCurrentProvisions",
    "annualPayablesAndAccruedExpenses",
    "annualCurrentAccruedExpenses",
    "annualInterestPayable",
    "annualPayables",
    "annualOtherPayable",
    "annualDuetoRelatedPartiesCurrent",
    "annualDividendsPayable",
    "annualTotalTaxPayable",
    "annualIncomeTaxPayable",
    "annualAccountsPayable",
    "annualTotalAssets",
    "annualTotalNonCurrentAssets",
    "annualOtherNonCurrentAssets",
    "annualDefinedPensionBenefit",
    "annualNonCurrentPrepaidAssets",
    "annualNonCurrentDeferredAssets",
    "annualNonCurrentDeferredTaxesAssets",
    "annualDuefromRelatedPartiesNonCurrent",
    "annualNonCurrentNoteReceivables",
    "annualNonCurrentAccountsReceivable",
    "annualFinancialAssets",
    "annualInvestmentsAndAdvances",
    "annualOtherInvestments",
    "annualInvestmentinFinancialAssets",
    "annualHeldToMaturitySecurities",
    "annualAvailableForSaleSecurities",
    "annualFinancialAssetsDesignatedasFairValueThroughProfitorLossTotal",
    "annualTradingSecurities",
    "annualLongTermEquityInvestment",
    "annualInvestmentsinJointVenturesatCost",
    "annualInvestmentsInOtherVenturesUnderEquityMethod",
    "annualInvestmentsinAssociatesatCost",
    "annualInvestmentsinSubsidiariesatCost",
    "annualInvestmentProperties",
    "annualGoodwillAndOtherIntangibleAssets",
    "annualOtherIntangibleAssets",
    "annualGoodwill",
    "annualNetPPE",
    "annualAccumulatedDepreciation",
    "annualGrossPPE",
    "annualLeases",
    "annualConstructionInProgress",
    "annualOtherProperties",
    "annualMachineryFurnitureEquipment",
    "annualBuildingsAndImprovements",
    "annualLandAndImprovements",
    "annualProperties",
    "annualCurrentAssets",
    "annualOtherCurrentAssets",
    "annualHedgingAssetsCurrent",
    "annualAssetsHeldForSaleCurrent",
    "annualCurrentDeferredAssets",
    "annualCurrentDeferredTaxesAssets",
    "annualRestrictedCash",
    "annualPrepaidAssets",
    "annualInventory",
    "annualInventoriesAdjustmentsAllowances",
    "annualOtherInventories",
    "annualFinishedGoods",
    "annualWorkInProcess",
    "annualRawMaterials",
    "annualReceivables",
    "annualReceivablesAdjustmentsAllowances",
    "annualOtherReceivables",
    "annualDuefromRelatedPartiesCurrent",
    "annualTaxesReceivable",
    "annualAccruedInterestReceivable",
    "annualNotesReceivable",
    "annualLoansReceivable",
    "annualAccountsReceivable",
    "annualAllowanceForDoubtfulAccountsReceivable",
    "annualGrossAccountsReceivable",
    "annualCashCashEquivalentsAndShortTermInvestments",
    "annualOtherShortTermInvestments",
    "annualCashAndCashEquivalents",
    "annualCashEquivalents",
    "annualCashFinancial",
]

QUARTERLY_BALANCE_SHEET_COLUMNS = [
    "quarterlyTreasurySharesNumber",
    "quarterlyPreferredSharesNumber",
    "quarterlyOrdinarySharesNumber",
    "quarterlyShareIssued",
    "quarterlyNetDebt",
    "quarterlyTotalDebt",
    "quarterlyTangibleBookValue",
    "quarterlyInvestedCapital",
    "quarterlyWorkingCapital",
    "quarterlyNetTangibleAssets",
    "quarterlyCapitalLeaseObligations",
    "quarterlyCommonStockEquity",
    "quarterlyPreferredStockEquity",
    "quarterlyTotalCapitalization",
    "quarterlyTotalEquityGrossMinorityInterest",
    "quarterlyMinorityInterest",
    "quarterlyStockholdersEquity",
    "quarterlyOtherEquityInterest",
    "quarterlyGainsLossesNotAffectingRetainedEarnings",
    "quarterlyOtherEquityAdjustments",
    "quarterlyFixedAssetsRevaluationReserve",
    "quarterlyForeignCurrencyTranslationAdjustments",
    "quarterlyMinimumPensionLiabilities",
    "quarterlyUnrealizedGainLoss",
    "quarterlyTreasuryStock",
    "quarterlyRetainedEarnings",
    "quarterlyAdditionalPaidInCapital",
    "quarterlyCapitalStock",
    "quarterlyOtherCapitalStock",
    "quarterlyCommonStock",
    "quarterlyPreferredStock",
    "quarterlyTotalPartnershipCapital",
    "quarterlyGeneralPartnershipCapital",
    "quarterlyLimitedPartnershipCapital",
    "quarterlyTotalLiabilitiesNetMinorityInterest",
    "quarterlyTotalNonCurrentLiabilitiesNetMinorityInterest",
    "quarterlyOtherNonCurrentLiabilities",
    "quarterlyLiabilitiesHeldforSaleNonCurrent",
    "quarterlyRestrictedCommonStock",
    "quarterlyPreferredSecuritiesOutsideStockEquity",
    "quarterlyDerivativeProductLiabilities",
    "quarterlyEmployeeBenefits",
    "quarterlyNonCurrentPensionAndOtherPostretirementBenefitPlans",
    "quarterlyNonCurrentAccruedExpenses",
    "quarterlyDuetoRelatedPartiesNonCurrent",
    "quarterlyTradeandOtherPayablesNonCurrent",
    "quarterlyNonCurrentDeferredLiabilities",
    "quarterlyNonCurrentDeferredRevenue",
    "quarterlyNonCurrentDeferredTaxesLiabilities",
    "quarterlyLongTermDebtAndCapitalLeaseObligation",
    "quarterlyLongTermCapitalLeaseObligation",
    "quarterlyLongTermDebt",
    "quarterlyLongTermProvisions",
    "quarterlyCurrentLiabilities",
    "quarterlyOtherCurrentLiabilities",
    "quarterlyCurrentDeferredLiabilities",
    "quarterlyCurrentDeferredRevenue",
    "quarterlyCurrentDeferredTaxesLiabilities",
    "quarterlyCurrentDebtAndCapitalLeaseObligation",
    "quarterlyCurrentCapitalLeaseObligation",
    "quarterlyCurrentDebt",
    "quarterlyOtherCurrentBorrowings",
    "quarterlyLineOfCredit",
    "quarterlyCommercialPaper",
    "quarterlyCurrentNotesPayable",
    "quarterlyPensionandOtherPostRetirementBenefitPlansCurrent",
    "quarterlyCurrentProvisions",
    "quarterlyPayablesAndAccruedExpenses",
    "quarterlyCurrentAccruedExpenses",
    "quarterlyInterestPayable",
    "quarterlyPayables",
    "quarterlyOtherPayable",
    "quarterlyDuetoRelatedPartiesCurrent",
    "quarterlyDividendsPayable",
    "quarterlyTotalTaxPayable",
    "quarterlyIncomeTaxPayable",
    "quarterlyAccountsPayable",
    "quarterlyTotalAssets",
    "quarterlyTotalNonCurrentAssets",
    "quarterlyOtherNonCurrentAssets",
    "quarterlyDefinedPensionBenefit",
    "quarterlyNonCurrentPrepaidAssets",
    "quarterlyNonCurrentDeferredAssets",
    "quarterlyNonCurrentDeferredTaxesAssets",
    "quarterlyDuefromRelatedPartiesNonCurrent",
    "quarterlyNonCurrentNoteReceivables",
    "quarterlyNonCurrentAccountsReceivable",
    "quarterlyFinancialAssets",
    "quarterlyInvestmentsAndAdvances",
    "quarterlyOtherInvestments",
    "quarterlyInvestmentinFinancialAssets",
    "quarterlyHeldToMaturitySecurities",
    "quarterlyAvailableForSaleSecurities",
    "quarterlyFinancialAssetsDesignatedasFairValueThroughProfitorLossTotal",
    "quarterlyTradingSecurities",
    "quarterlyLongTermEquityInvestment",
    "quarterlyInvestmentsinJointVenturesatCost",
    "quarterlyInvestmentsInOtherVenturesUnderEquityMethod",
    "quarterlyInvestmentsinAssociatesatCost",
    "quarterlyInvestmentsinSubsidiariesatCost",
    "quarterlyInvestmentProperties",
    "quarterlyGoodwillAndOtherIntangibleAssets",
    "quarterlyOtherIntangibleAssets",
    "quarterlyGoodwill",
    "quarterlyNetPPE",
    "quarterlyAccumulatedDepreciation",
    "quarterlyGrossPPE",
    "quarterlyLeases",
    "quarterlyConstructionInProgress",
    "quarterlyOtherProperties",
    "quarterlyMachineryFurnitureEquipment",
    "quarterlyBuildingsAndImprovements",
    "quarterlyLandAndImprovements",
    "quarterlyProperties",
    "quarterlyCurrentAssets",
    "quarterlyOtherCurrentAssets",
    "quarterlyHedgingAssetsCurrent",
    "quarterlyAssetsHeldForSaleCurrent",
    "quarterlyCurrentDeferredAssets",
    "quarterlyCurrentDeferredTaxesAssets",
    "quarterlyRestrictedCash",
    "quarterlyPrepaidAssets",
    "quarterlyInventory",
    "quarterlyInventoriesAdjustmentsAllowances",
    "quarterlyOtherInventories",
    "quarterlyFinishedGoods",
    "quarterlyWorkInProcess",
    "quarterlyRawMaterials",
    "quarterlyReceivables",
    "quarterlyReceivablesAdjustmentsAllowances",
    "quarterlyOtherReceivables",
    "quarterlyDuefromRelatedPartiesCurrent",
    "quarterlyTaxesReceivable",
    "quarterlyAccruedInterestReceivable",
    "quarterlyNotesReceivable",
    "quarterlyLoansReceivable",
    "quarterlyAccountsReceivable",
    "quarterlyAllowanceForDoubtfulAccountsReceivable",
    "quarterlyGrossAccountsReceivable",
    "quarterlyCashCashEquivalentsAndShortTermInvestments",
    "quarterlyOtherShortTermInvestments",
    "quarterlyCashAndCashEquivalents",
    "quarterlyCashEquivalents",
    "quarterlyCashFinancial",
]

ANNUAL_FINANCIALS_COLUMNS = [
    "annualTaxEffectOfUnusualItems",
    "annualTaxRateForCalcs",
    "annualNormalizedEBITDA",
    "annualNormalizedDilutedEPS",
    "annualNormalizedBasicEPS",
    "annualTotalUnusualItems",
    "annualTotalUnusualItemsExcludingGoodwill",
    "annualNetIncomeFromContinuingOperationNetMinorityInterest",
    "annualReconciledDepreciation",
    "annualReconciledCostOfRevenue",
    "annualEBITDA",
    "annualEBIT",
    "annualNetInterestIncome",
    "annualInterestExpense",
    "annualInterestIncome",
    "annualContinuingAndDiscontinuedDilutedEPS",
    "annualContinuingAndDiscontinuedBasicEPS",
    "annualNormalizedIncome",
    "annualNetIncomeFromContinuingAndDiscontinuedOperation",
    "annualTotalExpenses",
    "annualRentExpenseSupplemental",
    "annualReportedNormalizedDilutedEPS",
    "annualReportedNormalizedBasicEPS",
    "annualTotalOperatingIncomeAsReported",
    "annualDividendPerShare",
    "annualDilutedAverageShares",
    "annualBasicAverageShares",
    "annualDilutedEPS",
    "annualDilutedEPSOtherGainsLosses",
    "annualTaxLossCarryforwardDilutedEPS",
    "annualDilutedAccountingChange",
    "annualDilutedExtraordinary",
    "annualDilutedDiscontinuousOperations",
    "annualDilutedContinuousOperations",
    "annualBasicEPS",
    "annualBasicEPSOtherGainsLosses",
    "annualTaxLossCarryforwardBasicEPS",
    "annualBasicAccountingChange",
    "annualBasicExtraordinary",
    "annualBasicDiscontinuousOperations",
    "annualBasicContinuousOperations",
    "annualDilutedNIAvailtoComStockholders",
    "annualAverageDilutionEarnings",
    "annualNetIncomeCommonStockholders",
    "annualOtherunderPreferredStockDividend",
    "annualPreferredStockDividends",
    "annualNetIncome",
    "annualMinorityInterests",
    "annualNetIncomeIncludingNoncontrollingInterests",
    "annualNetIncomeFromTaxLossCarryforward",
    "annualNetIncomeExtraordinary",
    "annualNetIncomeDiscontinuousOperations",
    "annualNetIncomeContinuousOperations",
    "annualEarningsFromEquityInterestNetOfTax",
    "annualTaxProvision",
    "annualPretaxIncome",
    "annualOtherIncomeExpense",
    "annualOtherNonOperatingIncomeExpenses",
    "annualSpecialIncomeCharges",
    "annualGainOnSaleOfPPE",
    "annualGainOnSaleOfBusiness",
    "annualOtherSpecialCharges",
    "annualWriteOff",
    "annualImpairmentOfCapitalAssets",
    "annualRestructuringAndMergernAcquisition",
    "annualSecuritiesAmortization",
    "annualEarningsFromEquityInterest",
    "annualGainOnSaleOfSecurity",
    "annualNetNonOperatingInterestIncomeExpense",
    "annualTotalOtherFinanceCost",
    "annualInterestExpenseNonOperating",
    "annualInterestIncomeNonOperating",
    "annualOperatingIncome",
    "annualOperatingExpense",
    "annualOtherOperatingExpenses",
    "annualOtherTaxes",
    "annualProvisionForDoubtfulAccounts",
    "annualDepreciationAmortizationDepletionIncomeStatement",
    "annualDepletionIncomeStatement",
    "annualDepreciationAndAmortizationInIncomeStatement",
    "annualAmortization",
    "annualAmortizationOfIntangiblesIncomeStatement",
    "annualDepreciationIncomeStatement",
    "annualResearchAndDevelopment",
    "annualSellingGeneralAndAdministration",
    "annualSellingAndMarketingExpense",
    "annualGeneralAndAdministrativeExpense",
    "annualOtherGandA",
    "annualInsuranceAndClaims",
    "annualRentAndLandingFees",
    "annualSalariesAndWages",
    "annualGrossProfit",
    "annualCostOfRevenue",
    "annualTotalRevenue",
    "annualExciseTaxes",
    "annualOperatingRevenue",
]

QUARTERLY_FINANCIALS_COLUMNS = [
    "quarterlyTaxEffectOfUnusualItems",
    "quarterlyTaxRateForCalcs",
    "quarterlyNormalizedEBITDA",
    "quarterlyNormalizedDilutedEPS",
    "quarterlyNormalizedBasicEPS",
    "quarterlyTotalUnusualItems",
    "quarterlyTotalUnusualItemsExcludingGoodwill",
    "quarterlyNetIncomeFromContinuingOperationNetMinorityInterest",
    "quarterlyReconciledDepreciation",
    "quarterlyReconciledCostOfRevenue",
    "quarterlyEBITDA",
    "quarterlyEBIT",
    "quarterlyNetInterestIncome",
    "quarterlyInterestExpense",
    "quarterlyInterestIncome",
    "quarterlyContinuingAndDiscontinuedDilutedEPS",
    "quarterlyContinuingAndDiscontinuedBasicEPS",
    "quarterlyNormalizedIncome",
    "quarterlyNetIncomeFromContinuingAndDiscontinuedOperation",
    "quarterlyTotalExpenses",
    "quarterlyRentExpenseSupplemental",
    "quarterlyReportedNormalizedDilutedEPS",
    "quarterlyReportedNormalizedBasicEPS",
    "quarterlyTotalOperatingIncomeAsReported",
    "quarterlyDividendPerShare",
    "quarterlyDilutedAverageShares",
    "quarterlyBasicAverageShares",
    "quarterlyDilutedEPS",
    "quarterlyDilutedEPSOtherGainsLosses",
    "quarterlyTaxLossCarryforwardDilutedEPS",
    "quarterlyDilutedAccountingChange",
    "quarterlyDilutedExtraordinary",
    "quarterlyDilutedDiscontinuousOperations",
    "quarterlyDilutedContinuousOperations",
    "quarterlyBasicEPS",
    "quarterlyBasicEPSOtherGainsLosses",
    "quarterlyTaxLossCarryforwardBasicEPS",
    "quarterlyBasicAccountingChange",
    "quarterlyBasicExtraordinary",
    "quarterlyBasicDiscontinuousOperations",
    "quarterlyBasicContinuousOperations",
    "quarterlyDilutedNIAvailtoComStockholders",
    "quarterlyAverageDilutionEarnings",
    "quarterlyNetIncomeCommonStockholders",
    "quarterlyOtherunderPreferredStockDividend",
    "quarterlyPreferredStockDividends",
    "quarterlyNetIncome",
    "quarterlyMinorityInterests",
    "quarterlyNetIncomeIncludingNoncontrollingInterests",
    "quarterlyNetIncomeFromTaxLossCarryforward",
    "quarterlyNetIncomeExtraordinary",
    "quarterlyNetIncomeDiscontinuousOperations",
    "quarterlyNetIncomeContinuousOperations",
    "quarterlyEarningsFromEquityInterestNetOfTax",
    "quarterlyTaxProvision",
    "quarterlyPretaxIncome",
    "quarterlyOtherIncomeExpense",
    "quarterlyOtherNonOperatingIncomeExpenses",
    "quarterlySpecialIncomeCharges",
    "quarterlyGainOnSaleOfPPE",
    "quarterlyGainOnSaleOfBusiness",
    "quarterlyOtherSpecialCharges",
    "quarterlyWriteOff",
    "quarterlyImpairmentOfCapitalAssets",
    "quarterlyRestructuringAndMergernAcquisition",
    "quarterlySecuritiesAmortization",
    "quarterlyEarningsFromEquityInterest",
    "quarterlyGainOnSaleOfSecurity",
    "quarterlyNetNonOperatingInterestIncomeExpense",
    "quarterlyTotalOtherFinanceCost",
    "quarterlyInterestExpenseNonOperating",
    "quarterlyInterestIncomeNonOperating",
    "quarterlyOperatingIncome",
    "quarterlyOperatingExpense",
    "quarterlyOtherOperatingExpenses",
    "quarterlyOtherTaxes",
    "quarterlyProvisionForDoubtfulAccounts",
    "quarterlyDepreciationAmortizationDepletionIncomeStatement",
    "quarterlyDepletionIncomeStatement",
    "quarterlyDepreciationAndAmortizationInIncomeStatement",
    "quarterlyAmortization",
    "quarterlyAmortizationOfIntangiblesIncomeStatement",
    "quarterlyDepreciationIncomeStatement",
    "quarterlyResearchAndDevelopment",
    "quarterlySellingGeneralAndAdministration",
    "quarterlySellingAndMarketingExpense",
    "quarterlyGeneralAndAdministrativeExpense",
    "quarterlyOtherGandA",
    "quarterlyInsuranceAndClaims",
    "quarterlyRentAndLandingFees",
    "quarterlySalariesAndWages",
    "quarterlyGrossProfit",
    "quarterlyCostOfRevenue",
    "quarterlyTotalRevenue",
    "quarterlyExciseTaxes",
    "quarterlyOperatingRevenue",
]
